==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_es.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Que gloriosa civilización. Tantas centurias bajo el agua y sus ascensores siguen funcionando.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Especialmente, cuando los empujamos.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Pero sólo hacia abajo.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("¿Ves esa concha?")


dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")
dialogStr("Es un antiguo talismán para constructores de ascensores quienes siempre dicen 'Construya bien. Construya con Shell'.")


dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")
dialogStr("¿No te parece esa concha un poco familiar?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Deberían de avergonzarse de si mismos. Este es un comercial subliminal.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Esa calavera luce familiar.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Todas las calaveras humanas lucen igual... No como los esqueletos de peces.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Este es un duro camino.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Me siento como un ratón en una rueda de molino.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("¿Una rueda de molino para peces? Pero si sólo tenemos aletas.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")
dialogStr("Hoo, hooooo, hoooo... Estoy aquiiiii... ")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")
dialogStr("Hooo, si quieren les diré como resolver todos los niveles...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Hooo, ho hooo, ¡Yo sé por que la ciudad se hunde!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")
dialogStr("Hoooo, ¿Porqué nadie me presta atención?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("¡Hoooo ho hooo! ¿Porqué me ignoran?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hooooo, hooooo, ¡pez! ¡Póneme atención!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_es.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Que gloriosa civilización. Tantas centurias bajo el agua y sus ascensores siguen funcionando.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Especialmente, cuando los empujamos.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Pero sólo hacia abajo.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("¿Ves esa concha?")


dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")
dialogStr("Es un antiguo talismán para constructores de ascensores quienes siempre dicen 'Construya bien. Construya con Shell'.")


dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")
dialogStr("¿No te parece esa concha un poco familiar?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Deberían de avergonzarse de si mismos. Este es un comercial subliminal.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Esa calavera luce familiar.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Todas las calaveras humanas lucen igual... No como los esqueletos de peces.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Este es un duro camino.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Me siento como un ratón en una rueda de molino.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("¿Una rueda de molino para peces? Pero si sólo tenemos aletas.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")
dialogStr("Hoo, hooooo, hoooo... Estoy aquiiiii... ")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")
dialogStr("Hooo, si quieren les diré como resolver todos los niveles...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Hooo, ho hooo, ¡Yo sé por que la ciudad se hunde!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")
dialogStr("Hoooo, ¿Porqué nadie me presta atención?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("¡Hoooo ho hooo! ¿Porqué me ignoran?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hooooo, hooooo, ¡pez! ¡Póneme atención!")
